formfactor (ff)
===============

.. automodule:: jscatter.formfactor
    :noindex:
   
Form Factors
------------
.. autosummary::
    beaucage
    genGuinier
    guinier
    gaussianChain
    sphere
    sphereCoreShell
    ellipsoid
    multiShellSphere
    multiShellEllipsoid
    multiShellCylinder
    multilamellarVesicles
    cuboid
    sphereFuzzySurface
    sphereGaussianCorona
    pearlNecklace
    wormlikeChain
    teubnerStrey
    ellipsoidFilledCylinder
    superball

addons
------
.. autosummary::
    cloudScattering
    orientedCloudScattering
    scatteringFromSizeDistribution

------

.. automodule:: jscatter.formfactor
    :members:
    :undoc-members:
    :show-inheritance:
   

   
   
   